@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: timeval.cc 231 2005-11-29 15:04:05Z  $ */
+/* $Id: timeval.cc 749 2008-12-10 14:23:33Z jjongsma $ */
 
 /* timeval.cc
  *
@@ -20,10 +20,6 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glib/gmain.h>
-#include <glib/gmessages.h>
-#include <glib/gtimer.h>
-
 #include <glibmm/timeval.h>
 
 
